=== modified file 'drizzled/info_schema.h'
--- drizzled/info_schema.h	2009-06-17 05:04:46 +0000
+++ drizzled/info_schema.h	2009-06-17 19:39:27 +0000
@@ -18,13 +18,24 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/* Structs that defines the Table */
-
 #ifndef DRIZZLED_INFO_SCHEMA_H
 #define DRIZZLED_INFO_SCHEMA_H
 
+/**
+ * @file
+ *   info_schema.h
+ * @brief 
+ *   Header file which contains all classes related to I_S
+ */
+
 typedef class Item COND;
 
+/**
+ * @class 
+ *   InfoSchemaMethods
+ * @brief
+ *   The methods that an I_S table can support
+ */
 class InfoSchemaMethods
 {
 public:
@@ -169,8 +180,10 @@
 };
 
 /**
- * @class InfoSchemaTable
- * @brief Represents an I_S table.
+ * @class 
+ *   InfoSchemaTable
+ * @brief 
+ *   Represents an I_S table.
  */
 class InfoSchemaTable
 {
@@ -180,11 +193,13 @@
                   int idxField1,
                   int idxField2,
                   bool inHidden,
+                  bool inOptPossible,
                   uint32_t reqObject,
                   InfoSchemaMethods *inMethods)
     :
       table_name(tabName),
       hidden(inHidden),
+      is_opt_possible(inOptPossible),
       first_field_index(idxField1),
       second_field_index(idxField2),
       requested_object(reqObject),
@@ -195,7 +210,8 @@
   InfoSchemaTable()
     :
       table_name(NULL),
-      hidden(0),
+      hidden(false),
+      is_opt_possible(false),
       first_field_index(0),
       second_field_index(0),
       requested_object(0),
@@ -212,18 +228,35 @@
     i_s_methods= new_methods;
   }
 
+  /**
+   * @param[in] session
+   * @param[in] table_list
+   */
   Table *createSchemaTable(Session *session, TableList *table_list) const
   {
     Table *retval= i_s_methods->createSchemaTable(session, table_list);
     return retval;
   }
 
+  /**
+   * @param[in] session
+   * @param[in] tables
+   * @param[in] cond
+   */
   int fillTable(Session *session, TableList *tables, COND *cond)
   {
     int retval= i_s_methods->fillTable(session, tables, cond);
     return retval;
   }
 
+  /**
+   * @param[in] session
+   * @param[in] tables
+   * @param[in] table
+   * @param[in] res
+   * @param[in] db_name
+   * @param[in] tab_name
+   */
   int processTable(Session *session, TableList *tables, Table *table,
                    bool res, LEX_STRING *db_name, LEX_STRING *tab_name) const
   {
@@ -232,6 +265,10 @@
     return retval;
   }
 
+  /**
+   * @param[in] session
+   * @param[in] schema_table
+   */
   int oldFormat(Session *session, InfoSchemaTable *schema_table) const
   {
     int retval= i_s_methods->oldFormat(session, schema_table);
@@ -288,6 +325,16 @@
   }
 
   /**
+   * @return true if I_S optimizations can be performed on this
+   *         I_S table when running the fillTable method; false
+   *         otherwise.
+   */
+  bool isOptimizationPossible() const
+  {
+    return is_opt_possible;
+  }
+
+  /**
    * @return the index for the first field.
    */
   int getFirstFieldIndex() const
@@ -360,6 +407,13 @@
   bool hidden;
 
   /**
+   * Boolean which indicates whether optimizations are
+   * possible on this I_S table when performing the
+   * fillTable method.
+   */
+  bool is_opt_possible;
+
+  /**
    * The index of the first field.
    */
   int first_field_index;

=== modified file 'drizzled/show.cc'
--- drizzled/show.cc	2009-06-17 05:04:46 +0000
+++ drizzled/show.cc	2009-06-17 19:39:27 +0000
@@ -4044,6 +4044,11 @@
       /*if (session->lex->describe &&
           (table_list->schema_table->fill_table != get_all_tables))
         continue;*/
+      if (session->lex->describe &&
+          (table_list->schema_table->isOptimizationPossible() != true))
+      {
+        continue;
+      }
 
       /*
         If schema table is already processed and
@@ -4378,85 +4383,85 @@
 
 static InfoSchemaTable char_set_table("CHARACTER_SETS",
                                       charsets_fields_info,
-                                      -1, -1, 0, 0,
+                                      -1, -1, false, false, 0,
                                       &char_set_methods);
 static InfoSchemaTable collations_table("COLLATIONS",
                                         collation_fields_info,
-                                        -1, -1, 0, 0,
+                                        -1, -1, false, false, 0,
                                         &collations_methods);
 static InfoSchemaTable
   coll_char_set_table("COLLATION_CHARACTER_SET_APPLICABILITY",
                       coll_charset_app_fields_info,
-                      -1, -1, 0, 0,
+                      -1, -1, false, false, 0,
                       &coll_char_methods);
 static InfoSchemaTable columns_table("COLUMNS",
                                      columns_fields_info,
-                                     1, 2, 0, OPTIMIZE_I_S_TABLE,
+                                     1, 2, false, true, OPTIMIZE_I_S_TABLE,
                                      &columns_methods);
 static InfoSchemaTable global_stat_table("GLOBAL_STATUS",
                                          variables_fields_info,
-                                         -1, -1, 0, 0,
+                                         -1, -1, false, false, 0,
                                          &status_methods);
 static InfoSchemaTable global_var_table("GLOBAL_VARIABLES",
                                         variables_fields_info,
-                                        -1, -1, 0, 0,
+                                        -1, -1, false, false, 0,
                                         &variables_methods);
 static InfoSchemaTable key_col_usage_table("KEY_COLUMN_USAGE",
                                            key_column_usage_fields_info,
-                                           4, 5, 0, OPEN_TABLE_ONLY,
+                                           4, 5, false, true, OPEN_TABLE_ONLY,
                                            &key_col_usage_methods);
 static InfoSchemaTable open_tab_table("OPEN_TABLES",
                                       open_tables_fields_info,
-                                      -1, -1, 1, 0,
+                                      -1, -1, true, false, 0,
                                       &open_tables_methods);
 static InfoSchemaTable plugins_table("PLUGINS",
                                      plugin_fields_info,
-                                     -1, -1, 0, 0,
+                                     -1, -1, false, false, 0,
                                      &plugins_methods);
 static InfoSchemaTable process_list_table("PROCESSLIST",
                                           processlist_fields_info,
-                                          -1, -1, 0, 0,
+                                          -1, -1, false, false, 0,
                                           &processlist_methods);
 static InfoSchemaTable ref_constrain_table("REFERENTIAL_CONSTRAINTS",
                                            referential_constraints_fields_info,
-                                           1, 9, 0, OPEN_TABLE_ONLY,
+                                           1, 9, false, true, OPEN_TABLE_ONLY,
                                            &ref_constraints_methods);
 static InfoSchemaTable schemata_table("SCHEMATA",
                                       schema_fields_info,
-                                      1, -1, 0, 0,
+                                      1, -1, false, false, 0,
                                       &schemata_methods);
 static InfoSchemaTable sess_stat_table("SESSION_STATUS",
                                        variables_fields_info,
-                                       -1, -1, 0, 0,
+                                       -1, -1, false, false, 0,
                                        &status_methods);
 static InfoSchemaTable sess_var_table("SESSION_VARIABLES",
                                       variables_fields_info,
-                                      -1, -1, 0, 0,
+                                      -1, -1, false, false, 0,
                                       &variables_methods);
 static InfoSchemaTable stats_table("STATISTICS",
                                    stat_fields_info,
-                                   1, 2, 0,
+                                   1, 2, false, true,
                                    OPEN_TABLE_ONLY|OPTIMIZE_I_S_TABLE,
                                    &stats_methods);
 static InfoSchemaTable status_table("STATUS",
                                     variables_fields_info,
-                                    -1, -1, 1, 0,
+                                    -1, -1, true, false, 0,
                                     &status_methods);
 static InfoSchemaTable tables_table("TABLES",
                                     tables_fields_info,
-                                    1, 2, 0, OPTIMIZE_I_S_TABLE,
+                                    1, 2, false, true, OPTIMIZE_I_S_TABLE,
                                     &tables_methods);
 static InfoSchemaTable tab_constrain_table("TABLE_CONSTRAINTS",
                                            table_constraints_fields_info,
-                                           3, 4, 0, OPEN_TABLE_ONLY,
+                                           3, 4, false, true, OPEN_TABLE_ONLY,
                                            &tab_constraints_methods);
 static InfoSchemaTable tab_names_table("TABLE_NAMES",
                                        table_names_fields_info,
-                                       1, 2, 1, 0,
+                                       1, 2, true, true, 0,
                                        &tab_names_methods);
 static InfoSchemaTable var_table("VARIABLES",
                                  variables_fields_info,
-                                 -1, -1, 1, 0,
+                                 -1, -1, true, false, 0,
                                  &variables_methods);
 
 /*

